# Generated by Django 4.2.6 on 2023-10-17 08:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0002_alter_webstory_title'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='webstory',
            options={'ordering': ['first_published_at'], 'verbose_name': 'Web Story', 'verbose_name_plural': 'Web Stories'},
        ),
    ]
