# Generated by Django 4.2.6 on 2023-10-15 10:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webstory',
            name='title',
            field=models.CharField(default='Untitled', max_length=255, verbose_name='Title'),
        ),
    ]
