# Generated by Django 4.2.6 on 2023-10-22 14:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0007_webstoriessetting_google_analytics_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='webstoriessetting',
            name='auto_advance',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='webstoriessetting',
            name='default_page_duration',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='webstoriessetting',
            name='using_legacy_analytics',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='webstoriessetting',
            name='video_cache',
            field=models.BooleanField(default=False),
        ),
    ]
