# Generated by Django 4.2.6 on 2023-10-22 13:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0005_webstoriessetting_webstoriespublisherlogo'),
    ]

    operations = [
        migrations.AddField(
            model_name='webstoriespublisherlogo',
            name='default',
            field=models.BooleanField(default=False),
        ),
    ]
