# Generated by Django 4.2.6 on 2023-10-17 09:48

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0003_alter_webstory_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='webstory',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
