# Generated by Django 4.2.6 on 2023-10-22 14:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0008_webstoriessetting_auto_advance_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='webstoriessetting',
            name='default_page_duration',
            field=models.IntegerField(blank=True, default=7, null=True),
        ),
    ]
