# Generated by Django 4.2.6 on 2023-10-23 06:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_webstories_editor', '0009_alter_webstoriessetting_default_page_duration'),
    ]

    operations = [
        migrations.AddField(
            model_name='webstoriespublisherlogo',
            name='slug',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
